| diagnose_curves | R Documentation |
Diagnostic tools for functional epidemic curve models fitted with functional_curves().
Produces diagnostic plots without invoking base graphics.
diagnose_curves(x, grid_n = 200)
x |
An object of class |
grid_n |
Number of points used for the diagnostic smooth curve. |
An object of class "r4pde_curve_diagnostics" containing:
diagnostic data,
k-index checks,
concurvity estimates,
ggplot-based diagnostic panels.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.