This function fits three gradient models (exponential, power, and modified power) to given data. It then ranks the models based on their R-squared values and returns diagnostic plots for each model.
Value
A list containing:
- data
The input data, which will include an additional column 'mod_x'.
- results_table
A table of the model parameters and R-squared values.
- plot_exponential
Diagnostic plot for the exponential model.
- plot_power
Diagnostic plot for the power model.
- plot_modified_power
Diagnostic plot for the modified power model.
- plot_exponential_original
Plot of the original data with the exponential model fit.
- plot_power_original
Plot of the original data with the power model fit.
- plot_modified_power_original
Plot of the original data with the modified power model fit.
See also
Other Spatial analysis:
AFSD(),
BPL(),
count_subareas(),
count_subareas_random(),
join_count(),
oruns_test(),
oruns_test_boustrophedon(),
oruns_test_byrowcol(),
plot_AFSD()