simulate_dsp_data: #' Simulate Disease Suppression Profile Data

View source: R/functional_dsp.R

simulate_dsp_dataR Documentation

#' Simulate Disease Suppression Profile Data

Description

Simulates a dataset for demonstrating functional analysis with Disease Suppression Profiles. Returns a data frame with varying treatments and replicates over multiple time points.

Usage

simulate_dsp_data()

Value

A tibble with columns treatment, rep, time, y_control, dsp_true, severity_true, and severity.


r4pde documentation built on Sept. 8, 2026, 1:10 a.m.