View source: R/plot_functional_suppression_profiles.R
| plot.functional_suppression_profiles | R Documentation |
Plot functional suppression profiles
## S3 method for class 'functional_suppression_profiles'
plot(
x,
type = c("dendrogram", "profiles", "heatmap", "rank", "all"),
show_cut = TRUE,
show_points = FALSE,
...
)
x |
An object of class |
type |
Character string specifying the plot type. One of |
show_cut |
Logical; whether to display the cluster cut height in dendrogram. Default is |
show_points |
Logical; whether to overlay observed DSP values as points in the profiles plot. Default is |
... |
Additional arguments passed to specific plot functions. |
The plot method visualizes the components of a Functional Suppression Profile. The dendrogram defines the Functional Suppression Profiles based on temporal similarity. The heatmap is ordered by the dendrogram to help interpret these functional groups using summary metrics.
A ggplot object or a list of ggplot objects.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.