Plots environment-adjusted mean epidemic curves for each treatment, colored according to functional cluster membership.
The returned object is a ggplot and can be further modified
using standard ggplot2 layers.
Usage
plot_curves(x, ...)
# S3 method for class 'r4pde_compare_curves'
plot_curves(
x,
label_fun = NULL,
palette = NULL,
alpha = 0.9,
linewidth = 1.1,
...
)
# S3 method for class 'functional_distances'
plot_curves(
x,
label_fun = NULL,
palette = NULL,
alpha = 0.9,
linewidth = 1.1,
...
)
# S3 method for class 'functional_dsp'
plot_curves(x, ...)