| plot_curves | R Documentation |
Plots environment-adjusted mean epidemic curves for each treatment, colored according to functional cluster membership.
The returned object is a ggplot and can be further modified
using standard ggplot2 layers.
plot_curves(x, ...)
## S3 method for class 'functional_distances'
plot_curves(
x,
label_fun = NULL,
palette = NULL,
alpha = 0.9,
linewidth = 1.1,
...
)
## S3 method for class 'functional_dsp'
plot_curves(x, ...)
x |
An object of class |
... |
Additional arguments. |
label_fun |
Optional function to modify treatment labels. |
palette |
Optional named vector of colors for clusters. |
alpha |
Line transparency. |
linewidth |
Line width. |
A ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.