View source: R/functional_dsp.R
| rank_dsp | R Documentation |
Generates rankings of treatments based on extracted DSP functional descriptors.
rank_dsp(
summary_data,
metrics = c("protected_area", "max_suppression", "persistence", "centroid"),
higher_is_better = TRUE,
group = NULL,
ties.method = "average"
)
summary_data |
The tibble output from |
metrics |
Character vector of metrics to rank. |
higher_is_better |
Logical vector or named logical vector indicating if higher values are better for each metric. If a single logical, applies to all. |
group |
Optional character vector of grouping variables. |
ties.method |
Character string specifying how to handle ties. Default is |
A tibble with ranks for each specified metric, and an average_rank.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.