View source: R/functional_dsp.R
| simulate_dsp_data | R Documentation |
Simulates a dataset for demonstrating functional analysis with Disease Suppression Profiles. Returns a data frame with varying treatments and replicates over multiple time points.
simulate_dsp_data()
A tibble with columns treatment, rep, time, y_control, dsp_true, severity_true, and severity.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.